# This package contains macros that provide functionality relating to
# Software Collections. These macros are not used in default
# Fedora builds, and should not be blindly copied or enabled.
# Specifically, the "scl" macro must not be defined in official Fedora
# builds. For more information, see:
# http://docs.fedoraproject.org/en-US/Fedora_Contributor_Documentation
# /1/html/Software_Collections_Guide/index.html

%{?scl:%scl_package rubygem-%{gem_name}}
%{!?scl:%global pkg_name %{name}}

%global gem_name foreman_docker

%define rubyabi 1.9.1
%global foreman_dir /usr/share/foreman
%global foreman_bundlerd_dir %{foreman_dir}/bundler.d
%global foreman_pluginconf_dir %{foreman_dir}/config/settings.plugins.d

Summary:    A Foreman plugin for Docker container management
Name:       %{?scl_prefix}rubygem-%{gem_name}
Version:    1.2.0.18
Release:    1%{?dist}
Group:      Applications/System
License:    GPLv3
URL:        http://github.com/theforeman/foreman-docker
Source0:    %{gem_name}-%{version}.gem

Requires:   foreman-compute >= 1.6.0
Requires:   %{?scl_prefix}rubygem(docker-api) >= 1.17.0
Requires:   %{?scl_prefix}rubygem(docker-api) <  2.0.0
Requires:   %{?scl_prefix}rubygem(wicked) >= 1.1
Requires:   %{?scl_prefix}rubygem(wicked) < 2.0

BuildRequires: foreman-compute >= 1.7.0
BuildRequires: %{?scl_prefix}rubygem(docker-api) >= 1.13.0
BuildRequires: %{?scl_prefix}rubygem(docker-api) <  2.0.0
BuildRequires: %{?scl_prefix}rubygem(wicked) >= 1.1
BuildRequires: %{?scl_prefix}rubygem(wicked) < 2.0

%if 0%{?fedora} > 18
Requires: %{?scl_prefix}ruby(release)
%else
Requires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
%endif
Requires: %{?scl_prefix}rubygems

%if 0%{?fedora} > 18
BuildRequires: %{?scl_prefix}ruby(release)
%else
BuildRequires: %{?scl_prefix}ruby(abi) >= %{rubyabi}
%endif
BuildRequires: %{?scl_prefix}rubygems-devel
BuildRequires: %{?scl_prefix}rubygems
BuildRequires: foreman-assets

BuildArch: noarch

Provides: %{?scl_prefix}rubygem(%{gem_name}) = %{version}
Provides: foreman-plugin-docker
Provides: foreman-docker

%description
This plugin enables provisioning and managing Docker containers and images in
Foreman.

%package doc
BuildArch:  noarch
Requires:   %{?scl_prefix}%{pkg_name} = %{version}-%{release}
Summary:    Documentation for rubygem-%{gem_name}

%description doc
This package contains documentation for rubygem-%{gem_name}.

%prep
%setup -n %{pkg_name}-%{version} -q -c -T
mkdir -p .%{gem_dir}
%{?scl:scl enable %{scl} "}
gem install --local --install-dir .%{gem_dir} \
            --force %{SOURCE0} --no-rdoc --no-ri
%{?scl:"}

%build

%install
mkdir -p %{buildroot}%{gem_dir}
cp -a .%{gem_dir}/* \
        %{buildroot}%{gem_dir}/

%foreman_bundlerd_file
%foreman_precompile_plugin

%files
%dir %{gem_instdir}
%{gem_libdir}
%{gem_instdir}/app
%{gem_instdir}/config
%{gem_instdir}/db
%{gem_instdir}/locale
%{gem_spec}
%{foreman_bundlerd_plugin}
%{foreman_assets_plugin}
%doc %{gem_instdir}/LICENSE

%exclude %{gem_instdir}/.*
%exclude %{gem_instdir}/Rakefile
%exclude %{gem_instdir}/test
%exclude %{gem_cache}

%files doc
%doc %{gem_instdir}/README.md

%posttrans
# We need to run the db:migrate after the install transaction
%foreman_db_migrate
%foreman_restart
exit 0

%changelog
* Tue Jun 23 2015 Daniel Lobato <elobatocs@gmail.com> 1.2.0.18-1
- bump version (elobatocs@gmail.com)

* Tue Jun 23 2015 Daniel Lobato <elobatocs@gmail.com> 1.2.0.17-1
- bump version (elobatocs@gmail.com)

* Tue Jun 23 2015 Daniel Lobato <elobatocs@gmail.com> 1.2.0.16-1
-

* Tue Jun 23 2015 Daniel Lobato <elobatocs@gmail.com> 1.2.0.15-1
Fixes 1210496

* Thu May 21 2015 Mike McCune <mmccune@redhat.com> 1.2.0.14-1
- Fixes #10404 - Finds correct repo name for Docker Hub registry
  (paji@redhat.com)

* Tue May 19 2015 Mike McCune <mmccune@redhat.com> 1.2.0.13-1
- bz 1221387 - Fixes container provisioning issue (paji@redhat.com)

* Tue May 12 2015 Mike McCune <mmccune@redhat.com> 1.2.0.12-1
- Fixes #9393 - Allow users to create container without starting it (shlomi
  @ben-hanna.com)

* Tue May 05 2015 Mike McCune <mmccune@redhat.com> 1.2.0.11-1
- Fixes 9311 - Change the Katello tab text (daviddavis@redhat.com)
- Pull in final french strings from zanata (bkearney@redhat.com)

* Tue Apr 28 2015 Mike McCune <mmccune@redhat.com> 1.2.0.10-1
- Fixes #9901 - Better handling of errors in container api
  (daviddavis@redhat.com)
- Add in strings from zanata. All but french are done (bkearney@redhat.com)
- Fixes #9310, #9518 - Create containers using katello repos (paji@redhat.com)

* Wed Apr 22 2015 Mike McCune <mmccune@redhat.com> 1.2.0.9-1
- bumping version (mmccune@redhat.com)

* Tue Apr 21 2015 Mike McCune <mmccune@redhat.com> 1.2.0.8-1
- Fixes #9338: permission filters can be created now (dmitri@appliedlogic.ca)

* Tue Mar 24 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.7-1
- increment version (jmontleo@redhat.com)
- fixes #9544: added downcase_hash_keys mathod (dmitri@appliedlogic.ca)
- Merge branch 'bkearney/61strings' into 'SATELLITE-6.1.0' (mmccune@redhat.com)
- 98+ percent on all strings (bkearney@redhat.com)

* Thu Mar 19 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.6-1
- update version (jmontleo@redhat.com)

* Thu Mar 19 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.5-1
- Fixes #9830 - Fixing log call (daviddavis@redhat.com)
- Fixes #9829 - Revert image_search to old method (elobatocs@gmail.com)
- Fixes #9382 - Use connection info when connecting to docker
  (daviddavis@redhat.com)
- remove builder statement from releasers.conf (jmontleo@redhat.com)

* Tue Mar 17 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.4-1
- update version (jmontleo@redhat.com)
- Add the strings and the zanata file (bkearney@redhat.com)

* Tue Mar 10 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.3-1
- update version (jmontleo@redhat.com)
- fixes #9271: user is now informed about http connection errors when using
  search in the new container wizard. (dmitri@appliedlogic.ca)

* Mon Mar 02 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.2-1
- update version (jmontleo@redhat.com)
- Fixes #9570 - Only set username/password/email if present
  (daviddavis@redhat.com)
- Fixes #9562 - Fixing the baseurl in the containers api
  (daviddavis@redhat.com)

* Tue Feb 24 2015 Jason Montleon <jmontleo@redhat.com> 1.2.0.1-1
- update version for build (jmontleo@redhat.com)
- Merge tag '1.2.0' into SATELLITE-6.1.0 (jmontleo@redhat.com)
- Fixes #9456 - Validate docker registry URL (elobatocs@gmail.com)
- Bump version to 1.2.0 (elobatocs@gmail.com)
- Fixes #7874 - Docker Containers API (elobatocs@gmail.com)
- Fixes #9456 - Validate docker registry URL (elobatocs@gmail.com)
- Fixes #9242 - Backport image_search to fog 1.24 (elobatocs@gmail.com)
- fixes #9332 - Add yes/no text to managed info on containers index (shlomi
  @ben-hanna.com)
- refs #9341 - Updating the docker-api gem spec (paji@redhat.com)
- fixes #8033: container power on/off redirects to container view now
  (dmitri@appliedlogic.ca)

* Tue Feb 17 2015 Jason Montleon <jmontleo@redhat.com> 1.1.0.3-1
- fixes #9332 - Add yes/no text to managed info on containers index (shlomi
  @ben-hanna.com)

* Tue Feb 10 2015 Jason Montleon <jmontleo@redhat.com> 1.1.0.2-1
- fix gem version in rpm spec (jmontleo@redhat.com)

* Tue Feb 10 2015 Jason Montleon <jmontleo@redhat.com> 1.1.0.1-1
- Bump version to 1.1.0 (elobatocs@gmail.com)
- Fixes #9269 - Validate registry name (elobatocs@gmail.com)

* Tue Feb 10 2015 Daniel Lobato Garcia <dlobatog@redhat.com> 1.1.0-1
- Support katello content views to create containers

* Thu Feb 5 2015 Daniel Lobato Garcia <dlobatog@redhat.com> 1.0.1-1
- Fixes for 1.7 compatibility
- Do not list the assets directory twice. (slukasik@redhat.com)

* Mon Jan 12 2015 Daniel Lobato Garcia <dlobatog@redhat.com> 1.0.0-1
- Updating the version of foreman_docker to 1.0.0

* Wed Nov 05 2014 Dominic Cleal <dcleal@redhat.com> 0.2.0-2
- Precompile foreman_docker assets (dcleal@redhat.com)

* Mon Nov 3 2014 Daniel Lobato Garcia <dlobatog@redhat.com> 0.2.0-1
- Updating the version of foreman_docker to 0.2.0

* Tue Oct 21 2014 David Davis <daviddavis@redhat.com> 0.1.0-1
- Updating the version of foreman_docker to 0.1.0

* Tue Apr 29 2014 Dominic Cleal <dcleal@redhat.com> 0.0.3-1
- new package built with tito

